options nodate nonumber missing='-';

*  Close all ODS destinations, and then open when needed;

ods _all_ close;

*  Direct ODS output to the results window;

ods results;

*  ODS escape character used for inline formatting;

ods escapechar = '^';

*  Directory of input and output files;

%let PATH=C:\HOW\DelGobbo;

*  Library for input data;

libname sample "&PATH" access=read;

*;
*  Create a global macro variable with the
*  value of the study ID for use in a title.
*;

data _null_;
set sample.adsl(obs=1);
call symputx('STUDYID', studyid);
run;

*  Format used for N;

%let STATFMT0D=12.;

*  Format used for MIN and MAX requires two decimal places;

%let STATFMT2D=%sysevalf(&STATFMT0D + 0.2);

*  Format used for other statistics requires three decimal places;

%let STATFMT3D=%sysevalf(&STATFMT2D + 0.1);

*  Turn ODS graphics off;

ods graphics off;

*  Open the HTML destination to create the procedure output;

ods html path="&PATH" file='Statistics.htm' style=Journal;

*  Create data for the column headings of the report;

ods trace on;

ods output Summary=work.colhead;

title 'Data Used for the Column Headings of the Report';

proc summary print data=sample.adsl;
  class trt01pn trt01p;
run; quit;

*  Create the statistics for Section 1 of the report;

ods output Summary=work.summary;

title 'Statistics for Section 1 of the Report';

proc summary print data=sample.analysis missing stackods 
             n mean stderr median q1 q3 min max;
  class avisitn trt01pn;
  var chg;
run; quit;

*;
*  Create the statistics for Section 2 and Section 3 of the report.
*  Differences are computed in reference to the placebo 
*  (Active Drug - Placebo).
*;

ods output LSMeans=work.lsmeans SliceDiffs=work.diffs;

title 'Statistics for Sections 2 and 3 of the Report';

proc mixed data=sample.analysis;
  class usubjid avisitn trt01pn;
  model chg = avisitn trt01pn avisitn*trt01pn / ddfm=kenwardroger;
  repeated avisitn / subject=usubjid type=un;

  lsmeans avisitn*trt01pn / cl;
  slice   avisitn*trt01pn / cl diff=control('2' '0') sliceby=avisitn;
run; quit;

ods trace off;

*  Close the HTML destination;

ods html close;

*;
*  Add a record to the DIFFS table to represent the placebo. Statistics for
*  these records are missing.
*;

proc sort data=work.diffs out=work.diffs_sorted; by slice; run; quit;

data work.diffs2(drop=stmtno effect slice _trt01pn);
set work.diffs_sorted;
by slice;
length avisitn 8.;
avisitn = input(scan(slice, 2), best.);
output;
if (last.slice) then do;
  trt01pn = _trt01pn;
  call missing(of estimate stderr df tvalue probt alpha lower upper);
  output;
end;
run;

*;
*  Create the input control data set and format used later to create the
*  column headings.
*;

data work.colhead_cntlin(drop=trt01pn trt01p nobs first_space);
set work.colhead;
length fmtname $7 type $1 start end 8 label $30 first_space 8;

*  Replace the first blank space in the label with the split character;

first_space = index(strip(trt01p), ' ');

if (first_space ne 0)
  then substr(trt01p, first_space, 1) = '~';

*  Specify the required information for the format;

fmtname = 'COLHEAD';
type    = 'N';
start   = trt01pn;
end     = trt01pn;
label   = strip(trt01p) || '~(N = ' || strip(put(nobs, &STATFMT0D)) || ')';
run;

proc format cntlin=work.colhead_cntlin; run; quit;

*;
*  Create a separate row from specific column values of the 
*  Summary data - Section 1.
*;

data work.report_summary(keep=section rownum indent rowlbl cell 
                              avisitn trt01pn idlabel);
set work.summary;
by avisitn trt01pn;

length idlabel $30 rownum indent 8 rowlbl $40 cell $20; 

section = 1;

if (first.trt01pn) then rownum = 0;

*  Column heading;

idlabel = strip(put(trt01pn, colhead.));

* Row Heading;

rownum +1;
indent = 0;
rowlbl = 'Summary Statistics';
cell   = '';
output;

* Row Values; 

indent = 1;

rownum +1;
rowlbl = 'n';
cell   = strip(put(n, &STATFMT0D));
output;

rownum +1;
rowlbl = 'Mean';
cell   = strip(put(mean, &STATFMT3D));
output;

rownum +1;
rowlbl = 'SE';
cell   = strip(put(stderr, &STATFMT3D));
output;

rownum +1;
rowlbl = 'Median';
cell   = strip(put(median, &STATFMT3D));
output;

rownum +1;
rowlbl = 'Q1, Q3';
cell   = strip(put(q1, &STATFMT3D)) || ', ' || strip(put(q3, &STATFMT3D));
output;

rownum +1;
rowlbl = 'Min, Max';
cell   = strip(put(min, &STATFMT2D)) || ', ' || 
         strip(put(max, &STATFMT2D));
output;

run;

*;
*  Create a separate row from specific column values of the 
*  LS Means data - Section 2.
*;

proc sort data=work.lsmeans out=work.lsmeans_sorted; 
  by avisitn trt01pn;
run; quit;

data work.report_lsmeans(keep=section rownum indent rowlbl cell 
                              avisitn trt01pn idlabel);
set work.lsmeans_sorted;
by avisitn trt01pn;

length idlabel $30 rownum indent 8 rowlbl $40 cell $20; 

section = 2;

if (first.trt01pn) then rownum = 0;

*  Column heading;

idlabel = strip(put(trt01pn, colhead.));

* Blank row;

rownum +1;
indent = 0;
rowlbl = '';
cell   = '';
output;

* Row Heading;

indent = 0;
rownum +1;
rowlbl = 'LS Mean';
cell   = '';
output;

* Row Values;

indent = 1;

rownum +1;
rowlbl = 'Estimate (SE)';
cell   = strip(put(estimate, &STATFMT3D)) || 
         ' (' || strip(put(stderr, &STATFMT3D)) || ')';
output;

rownum +1;
rowlbl = '95% CI';
cell   = '('  || strip(put(lower, &STATFMT3D)) || 
         ', ' || strip(put(upper, &STATFMT3D)) || ')';
output;

run;

*;
*  Create a separate row from specific column values of the 
*  differences of LS Means data - Section 3.
*;

proc sort data=work.diffs2 out=work.diffs2_sorted;
  by avisitn trt01pn;
run; quit;

data work.report_diffs(keep=section rownum indent rowlbl cell 
                            avisitn trt01pn idlabel);
set work.diffs2_sorted;
by avisitn trt01pn;

length idlabel $30 rownum indent 8 rowlbl $40 cell $20; 

section = 3;

if (first.trt01pn) then rownum = 0;

*  Column heading;

idlabel = strip(put(trt01pn, colhead.));

* Blank row;

rownum +1;
indent = 0;
rowlbl = '';
cell   = '';
output;

* Row Heading; 

indent = 0;
rownum +1;
rowlbl = 'Treatment Difference (Active-Placebo)';
cell   = '';
output;

* Row Values;

indent = 1;

rownum +1;
rowlbl = 'Estimate (SE)';
cell   = strip(put(estimate, &STATFMT3D)) || 
         ' (' || strip(put(stderr, &STATFMT3D)) || ')';
output;

rownum +1;
rowlbl = '95% CI';
cell   = '('  || strip(put(lower, &STATFMT3D)) || 
         ', ' || strip(put(upper, &STATFMT3D)) || ')';
output;

rownum +1;
rowlbl = 'Nominal p-value';
cell   = strip(put(probt, pvalue6.4));
output;

run;

*  Merge the preliminary data into a single table;

data work.report1;
set work.report_summary
    work.report_lsmeans
    work.report_diffs;
run;

*  Sort in preparation for transposition;

proc sort data=work.report1 out=work.report1_sorted;
  by avisitn section rownum rowlbl indent trt01pn;
run; quit;

*  Transpose the data to get the layout needed for the report;

proc transpose data=work.report1_sorted prefix=trt_
               out=work.report_final(drop=_name_);
  by avisitn section rownum rowlbl indent;
  var cell;
  id trt01pn;
  idlabel idlabel;
run; quit;

*  Open the RTF destination to create the procedure output;

ods rtf file="&PATH\CHOL_Report.rtf" style=Journal bodytitle;

title1 'Table x.y: Change from Baseline LDL-C by Scheduled Visit';
title2 "Study &STUDYID";

proc report data=work.report_final nowd missing split='~'
    style(header)=[font_style=roman];
  columns avisitn section rownum indent rowlbl trt_: ;

  define avisitn / order order=internal noprint;
  define section / order order=internal noprint;
  define rownum  / order order=internal noprint;
  define indent  / noprint;
  define rowlbl  / display ' ' style(column)=[asis=on];
  define trt_:   / display center;

  break after avisitn / page;

  compute before avisitn / style=[just=l];
    text = catx(' ', 'Week', avisitn); 
    line text $;
  endcomp;

  compute rowlbl;
    *  Placeholder for superscript and indenting;
    if (rowlbl eq 'Summary Statistics')
      then rowlbl = cats(rowlbl, '^{super a}');
    else if (rowlbl eq 'LS Mean')
      then rowlbl = cats(rowlbl, '^{super b}');
    if (indent.sum ne 0)
      then rowlbl = cats('^{nbspace 3}', rowlbl);
  endcomp;

  compute after avisitn / style=[just=l];
    line ' ';
    line 'N = number of subjects randomized; Xanomeline Low Dose = 54 mg; Xanomeline High Dose = 81 mg.';
    line ' ';
    line '^{super a}Summary statistics are based on observed data.';
    line ' ';
    line '^{super b}LS mean is from a repeated measures model which includes effects: treatment group, scheduled';
    line 'visit, and the interaction of treatment with scheduled visit.';
  endcomp;

run; quit;

*  Close the RTF destination;

ods rtf close;

;*';*";*/;quit;run;
* Reference for code above: http://tinyurl.com/mjde9fc ;